@@ -5,7 +5,6 @@ use v5.26;
 package ChordPro::A2Crd;
 
 use ChordPro::Version;
-use ChordPro::Files;
 use ChordPro::Paths;
 use ChordPro::Chords;
 
@@ -19,7 +18,7 @@ ChordPro::A2Crd - convert lyrics and chords to ChordPro
 
   perl -MA2Crd -e run -- [ options ] [ file ... ]
 
-(But no one does that.)
+(But noone does that.)
 
 When the associated B<chordpro> program has been installed correctly:
 
@@ -39,20 +38,20 @@ Typical a2crd input:
 	  D          G    D
     Swing low, sweet chariot,
 			   A7
-    Comin' for to carry me home.
+    Comin’ for to carry me home.
 	  D7         G    D
     Swing low, sweet chariot,
 		  A7       D
-    Comin' for to carry me home.
+    Comin’ for to carry me home.
 
       D                       G          D
     I looked over Jordan, and what did I see,
 			   A7
-    Comin' for to carry me home.
+    Comin’ for to carry me home.
       D              G            D
-    A band of angels comin' after me,
+    A band of angels comin’ after me,
 		  A7       D
-    Comin' for to carry me home.
+    Comin’ for to carry me home.
 
 Note that the output from the conversion will generally need some
 additional editing to be useful as input to ChordPro.
@@ -90,6 +89,8 @@ package ChordPro::A2Crd;
 
 use ChordPro::Config;
 
+use File::LoadLines;
+use Encode qw(decode decode_utf8 encode_utf8);
 my $local_debug;
 
 # API: Main entry point.
@@ -104,7 +105,7 @@ sub a2crd {
     # Process input.
     my $lines = $opts->{lines}
       ? delete($opts->{lines})
-      : fs_load( @ARGV ? $ARGV[0] : \*STDIN);
+      : loadlines( @ARGV ? $ARGV[0] : \*STDIN);
 
     return [ a2cho($lines) ];
 }
@@ -531,7 +532,7 @@ sub format_comment_line
     $line =~ s/\[// ;
     $line =~ s/\]// ;
     return '' if $line eq '' ;
-    return "{comment: " . $line . "}" ;
+    return "{comment:" . $line . "}" ;
 }
 
 # Process the lines via the map.
@@ -539,8 +540,7 @@ my $infer_titles;
 sub maplines {
     my ( $map, $lines ) = @_;
     my @out;
-    $infer_titles = $config->{a2crd}->{'infer-titles'}
-      && !$options->{fragment};
+    $infer_titles //= $::config->{a2crd}->{'infer-titles'};
 
     # Preamble.
     # Pass empty lines.
@@ -944,6 +944,11 @@ sub app_setup {
         $clo->{"no$config"} = 1 unless $clo->{$config};
     }
 
+    ####TODO: Should decode all, and remove filename exception.
+    for ( keys %{ $clo->{define} } ) {
+	$clo->{define}->{$_} = decode_utf8($clo->{define}->{$_});
+    }
+
     # Plug in command-line options.
     @{$options}{keys %$clo} = values %$clo;
     # warn(Dumper($options), "\n") if $options->{debug};
