@@ -26,7 +26,6 @@ package ChordPro::Delegate::TextBlock;
 #  textstyle:  Style (font) to be used. Must be one of "text", "chords",
 #              "comment" etc.
 #  textsize:   Initial value for the text size.
-#  textspacing: Text spacing. A factor (e.g. 1.2) or "flex".
 #  textcolor:  Initial color for the text.
 #  background: Background color of the object.
 #
@@ -40,78 +39,63 @@ use ChordPro::Utils;
 
 sub DEBUG() { $::config->{debug}->{txtblk} }
 
-sub txt2xform( $self, %args ) {
-    my $elt = $args{elt};
+sub txt2xform( $s, $pw, $elt ) {
 
-    my $ps = $self->{_ps};
+    my $ps = $s->{_ps};
     my $pr = $ps->{pr};
     my $opts = { %{$elt->{opts}} };
 
     # Text style must be one of the known styles (text, chord, comment, ...).
     my $style = delete($opts->{textstyle}) // "text";
     unless ( defined($ps->{fonts}->{$style} ) ) {
-	warn("TextBlock: Unknown style \"$style\", using \"text\"\n");
+	warn("TextBlock: Unknown font style \"$style\", using \"text\"\n");
 	$style = "text";
     }
     my $font  = $ps->{fonts}->{$style};
-    my $bgcol = $pr->_bgcolor($font->{background});
-    $bgcol = "" if $bgcol eq "none";
-    my $vsp = delete($opts->{textspacing}) // "flex";
-    my $sp = $vsp eq "flex"
-      ? ($font->{leading} || $ps->{spacing}->{$style} || 1) : $vsp;
-    my $size   = fontsize( delete($opts->{textsize}), $font->{size} );
-    my $color  = delete($opts->{textcolor}) // $font->{color};
+
+    my $size   = delete($opts->{textsize}) || $font->{size};
+    my $color  = delete($opts->{textcolor});
     my $flush  = delete($opts->{flush})  // "left";
     my $vflush = delete($opts->{vflush}) // "top";
-    $color = $ps->{pr}->_fgcolor($color) if $color;
 
     my $data = $elt->{data};
-    if ( $color || $bgcol ) {
-	my $span = "";
-	$span .= " color='$color'" if $color;
-	$span .= " background='$bgcol'" if $bgcol;
-	$data = [ map { "<span$span>$_</span>" } @$data ];
+    if ( $color ) {
+	$data = [ map { "<span color='$color'>$_</span>" } @$data ];
     }
     my $padding  = delete($opts->{padding});
 
-    # New xo.
+    # New xo, and put it in text mode.
     my $xo = $pr->{pdf}->xo_form;
+    $xo->textstart;
 
     # Pre-pass to establish the actual width/height.
-    my ( $awidth, $aheight ) = ( 0, undef );
+    my ( $awidth, $aheight ) = ( 0, 0 );
     my ( $w, $h );
     for ( @$data ) {
 	( $w, $h ) = $pr->strwidth( $_, $font, $size );
 	$awidth = $w if $w > $awidth;
-	if ( defined($aheight) ) {
-	    $aheight += $vsp eq "flex" ? ($h||$size)*$sp : $size*$vsp;
-	}
-	else {
-	    $aheight = ($h||$size);
-	}
+	$aheight += $h * $ps->{spacing}->{lyrics};
     }
 
     # Desired width (includes padding).
     my ( $width, $height );
     if ( $width = delete($opts->{width}) ) {
-	# Note that using dimension is not yet operational.
-	$width = dimension( $width, width => $size ) - 2*($padding||0);
+	$width -= 2*($padding||0);
     }
     else {
 	$width = $awidth;
     }
 
     # Correction for tight y-fit.
-    my $ycorr = 0;#($vsp eq "flex" ? $h||$size : $size) * ($sp - 1);
+    my $ycorr = $h * ($ps->{spacing}->{lyrics} - 1);
 
     # Desired height (includes padding).
     if ( $height = delete($opts->{height}) ) {
-	# Note that using dimension is not yet operational.
-	$height = dimension( $height, width => $size ) - 2*($padding||0);
+	$height -= 2*($padding||0);
     }
     else {
-	$height = $aheight - $ycorr;
-	$ycorr = 0 unless defined($padding);
+	$height = $aheight;
+	$ycorr = 0 unless defined($padding);;
     }
     # Width and height are now the 'inner' box (w/o padding).
 
@@ -122,9 +106,6 @@ sub txt2xform( $self, %args ) {
     else {
 	$padding = 0;
     }
-    if ( $::config->{debug}->{txtblk} ) {
-	warn("tb: w = $width, h = $height, p = $padding, sp = $sp, c = $ycorr\n");
-    }
     # Note that the padding will be dealt with in the bbox.
 
     # Draw background.
@@ -135,9 +116,6 @@ sub txt2xform( $self, %args ) {
 	$xo->fill;
     }
 
-    # Put it in text mode.
-    $xo->textstart;
-
     my $y = $height - $ycorr;
 
     if ( $flush eq "right" || $flush eq "center"
@@ -151,19 +129,18 @@ sub txt2xform( $self, %args ) {
 	}
 
 	for ( @$data ) {
-	    my $h = $pr->strheight( $_, $font, $size ) || $size;
+	    my $w = $pr->strheight( $_, $font, $size );
 	    $pr->{tmplayout}->set_width($width);
 	    $pr->{tmplayout}->set_alignment($flush);
 	    $pr->{tmplayout}->show( 0, $y, $xo );
-	    $y -= ($vsp eq "flex" ? $h : $size) * $sp;
+	    $y -= $h * $ps->{spacing}->{lyrics};
 	}
     }
     else {			# assume top/left
 	for ( @$data ) {
-	    my $h = $pr->strheight( $_, $font, $size ) || $size;
-	    $pr->{tmplayout}->set_alignment($flush);
+	    my $h = $pr->strheight( $_, $font, $size );
 	    $pr->{tmplayout}->show( 0, $y, $xo );
-	    $y -= ($vsp eq "flex" ? $h : $size) * $sp;
+	    $y -= $h * $ps->{spacing}->{lyrics};
 	}
     }
 
@@ -172,7 +149,7 @@ sub txt2xform( $self, %args ) {
 
     return
       { type      => "image",
-	subtype   => "xform",
+	subtype   => "xoform",
 	line      => $elt->{line},
 	data      => $xo,
 	width     => $width  + 2*$padding,
