@@ -1,4 +1,4 @@
-#! perl
+#!/usr/bin/perl
 
 package main;
 
@@ -14,7 +14,6 @@ use ChordPro::Utils qw( demarkup is_true );
 use String::Interpolate::Named;
 use utf8;
 use POSIX qw(setlocale LC_TIME strftime);
-use Ref::Util qw( is_arrayref );
 
 use Exporter 'import';
 our @EXPORT;
@@ -31,9 +30,8 @@ sub fmt_subst {
 	####CHECK
 	$m->{_key} =
 	  [ map { ChordPro::Chords::transpose( $_, $capo ) }
-	    @{$m->{key}} ];
+	        @{$m->{key}} ];
     }
-    $m->{capo} = [] if $config->{settings}->{decapo};
     $m->{key_actual} //= $m->{key};
     $m->{tuning} //= [ join(" ", ChordPro::Chords::get_tuning) ];
     # If config->{instrument} is missing, or null, the program abends with
@@ -50,17 +48,15 @@ sub fmt_subst {
 	$m->{"user.fullname"} = [ $config->{user}->{fullname} ];
     }
     setlocale( LC_TIME, "" );
-    $m->{today} //= strftime( $config->{dates}->{today}->{format},
-			      localtime(time) );
-    $m->{chordpro} = "ChordPro";
-    $m->{"chordpro.version"} = $ChordPro::VERSION;
+    $m->{today} //= [ strftime( $config->{dates}->{today}->{format},
+				localtime(time) ) ];
+
     for ( keys %{ $config->{settings} } ) {
 	my $v = $config->{settings}->{$_};
 	$v = '' if $v =~ /^(0|false|off)$/i;
 	$v = 1  if $v=~ /^(true|on)$/i;
 	$m->{"settings.$_"} = $v;
     }
-
     interpolate( { %$s, args => $m,
 		   separator => $config->{metadata}->{separator} },
 		 $t );
@@ -170,7 +166,7 @@ sub prep_outlines {
 
     my @book;
     foreach my $song ( @$book ) {
-	my $meta = { %{$song->{meta}} };
+	my $meta = $song->{meta};
 	next if _suppresstoc($meta);
 
 	my @split;
@@ -180,7 +176,7 @@ sub prep_outlines {
 	    push( @split, [ $coreitem, [""] ] ), next unless $meta->{$coreitem};
 
 	    my @s = map { [ $_ ] }
-	      @{ is_arrayref( $meta->{$coreitem} )
+	      @{ UNIVERSAL::isa( $meta->{$coreitem}, 'ARRAY' )
 		? $meta->{$coreitem}
 		: [ $meta->{$coreitem} ]
 	    };
@@ -275,20 +271,16 @@ sub prep_outlines {
 
     # Sort.
     my $i = -1;
-    use Unicode::Collate;
-    my $collator = Unicode::Collate->new;
     my $srt =
       "sub { " .
       join( " or ",
 	    map { $i++;
 		  my ( $rev, $f ) = /^([-+]*)(.*)/;
 		  my $num = $rev =~ s/\+//g;
-		  my ( $a, $b ) = $rev =~ /-/ ? qw( b a ) : qw( a b );
-		  my $l = "\$$a"."->[$i]";
-		  my $r = "\$$b"."->[$i]";
 		  warn("F: $f, N: $num, R: $rev\n") if PODBG;
-		  $num ? "$l <=> $r" : "\$collator->cmp( $l, $r )"
-	       }
+		  "\$" . ( $rev =~ /-/ ? "b" : "a" ) . "->[$i] " .
+		  ($num ? '<=>' : 'cmp') .
+		  " \$" . ( $rev =~ /-/  ? "a" : "b" ) . "->[$i]" }
 		@{$ctl->{fields}} ) .
       " }";
     warn("SRT; $srt\n") if PODBG;
@@ -296,11 +288,7 @@ sub prep_outlines {
     @book =
       sort $srt
       map { my $t = $_;
-	    [ ( map { demarkup(lc(  ( index($_,"sort") && is_arrayref($t->{meta}->{"sort$_"})
-				      ? $t->{meta}->{"sort$_"}->[0]
-				      : undef ) //
-				   $t->{meta}->{$_}->[0] //
-				   "")) }
+	    [ ( map { demarkup(lc($t->{meta}->{$_}->[0] // "")) }
 		    @fields ),
 	      $_ ] }
 	  @book;
