@@ -8,7 +8,6 @@ use Carp;
 use feature 'state';
 use feature 'signatures';
 no warnings 'experimental::signatures';
-use ChordPro::Utils qw( is_ttrue );
 
 sub gridline( $elt, $x, $y, $cellwidth, $barwidth, $margin, $ps, %opts ) {
 
@@ -19,9 +18,8 @@ sub gridline( $elt, $x, $y, $cellwidth, $barwidth, $margin, $ps, %opts ) {
 
     # Use the chords font for the chords, and for the symbols size.
     my $fchord = { %{ $fonts->{grid} || $fonts->{chord} } };
-    my $schord = $fonts->{gridstrum};
     delete($fchord->{background});
-    $y -= $pr->font_bl($fchord);
+    $y -= font_bl($fchord);
 
     pr_label_maybe( $ps, $x, $y );
 
@@ -44,39 +42,22 @@ sub gridline( $elt, $x, $y, $cellwidth, $barwidth, $margin, $ps, %opts ) {
 
     if ( $margin->[0] ) {
 	$x -= $barwidth;
-	my $t = $elt->{margin};
-	if ( $t && $t->{chords} ) {
-	    if ( 0 && $::config->{settings}->{'chords-as-chords'} ) {
-		my $x = $x;
-		for ( 0..$#{ $t->{chords} } ) {
-		    $x = $pr->text( $t->{chords}->[$_]->chord_display,
-				    $x, $y, $fonts->{chord} )
-		      unless $t->{chords}->[$_] eq "";
-		    $x = $pr->text( $t->{phrases}->[$_],
-				    $x, $y, $fonts->{grid_margin} )
-		}
-	    }
-	    else {
+	if ( $elt->{margin} ) {
+	    my $t = $elt->{margin};
+	    if ( $t->{chords} ) {
 		$t->{text} = "";
 		for ( 0..$#{ $t->{chords} } ) {
-		    $t->{text} .= $t->{chords}->[$_]->chord_display
-		      unless $t->{chords}->[$_] eq "";
-		    $t->{text} .= $t->{phrases}->[$_];
+		    $t->{text} .= $t->{chords}->[$_]->chord_display . $t->{phrases}->[$_];
 		}
-		$pr->text( $t->{text}, $x, $y, $fonts->{grid_margin} );
 	    }
-	}
-	elsif ( $t ) {
-	    $pr->text( $t->{text}, $x, $y, $fonts->{grid_margin} );
+	    $pr->text( $t->{text}, $x, $y, $fonts->{comment} );
 	}
 	$x += $margin->[0] * $cellwidth + $barwidth;
     }
 
     my $ctl = $pr->{ps}->{grids}->{cellbar};
     my $col = $pr->{ps}->{grids}->{symbols}->{color};
-    $opts{subtype} //= $opts{type} eq "gridline" ? "cellbars" : "";
-    my $needcell = ( $opts{type} eq "gridline"
-		     || $opts{subtype} eq "cellbars" ) && $ctl->{width};
+    my $needcell = $ctl->{width};
 
     state $prevvoltastart;
     my $align;
@@ -114,13 +95,6 @@ sub gridline( $elt, $x, $y, $cellwidth, $barwidth, $margin, $ps, %opts ) {
 	    $lcr = 0 if $i > $firstbar;
 	    $lcr = 1 if $i == $lastbar;
 
-	    unless ( $opts{subtype} eq "cellbars" ) {
-		$x += $barwidth;
-		$prevbar = $i;
-		$needcell = 0;
-		next;
-	    }
-
 	    if ( $t eq "|" ) {
 		if ( $token->{volta} ) {
 		    if ( $align ) {
@@ -153,9 +127,6 @@ sub gridline( $elt, $x, $y, $cellwidth, $barwidth, $margin, $ps, %opts ) {
 	    elsif ( $t eq " %" ) { # repeat2Bars
 		pr_repeat( $x+$sz/2, $y, 0, $sz, $col, $pr );
 	    }
-	    elsif ( $t eq " %%" ) { # repeat2Bars
-		pr_repeat2( $x+$sz/2, $y, 0, $sz, $col, $pr );
-	    }
 	    else {
 		die($t);	# can't happen
 	    }
@@ -172,7 +143,7 @@ sub gridline( $elt, $x, $y, $cellwidth, $barwidth, $margin, $ps, %opts ) {
 		    && !is_bar($tokens[$k]) ) {
 		$k++;
 	    }
-	    $tokens[$k] = { symbol => " %%", class => "bar" };
+	    $tokens[$k] = { symbol => " %", class => "bar" };
 	    $x += $cellwidth;
 	    $needcell = 0;
 	    next;
@@ -181,17 +152,15 @@ sub gridline( $elt, $x, $y, $cellwidth, $barwidth, $margin, $ps, %opts ) {
 	pr_cellline( $x-$barwidth, $y, 0, $sz, $ctl->{width},
 		     $pr->_fgcolor($ctl->{color}), $pr )
 	  if $needcell;
-	$needcell = ( $opts{type} eq "gridline"
-		      || $opts{subtype} eq "cellbars" ) && $ctl->{width};
+	$needcell = $ctl->{width};
 
 	if ( $token->{class} eq "chord" || $token->{class} eq "chords" ) {
 	    my $tok = $token->{chords} // [ $token->{chord} ];
 	    my $cellwidth = $cellwidth / @$tok;
 	    for my $t ( @$tok ) {
 		$x += $cellwidth, next if $t eq '';
-		my $text = $t eq '/' ? $t : $t->chord_display;
-		$pr->text( $text, $x, $y,
-			   $t->info->is_gridstrum ? $schord : $fchord );
+		$t = $t->chord_display;
+		$pr->text( $t, $x, $y, $fchord );
 		$x += $cellwidth;
 	    }
 	}
@@ -235,10 +204,10 @@ sub gridline( $elt, $x, $y, $cellwidth, $barwidth, $margin, $ps, %opts ) {
 	if ( $t->{chords} ) {
 	    $t->{text} = "";
 	    for ( 0..$#{ $t->{chords} } ) {
-		$t->{text} .= $t->{chords}->[$_]->chord_display . $t->{phrases}->[$_];
+		$t->{text} .= $t->{chords}->[$_] . $t->{phrases}->[$_];
 	    }
 	}
-	$pr->text( " " . $t->{text}, $x, $y, $fonts->{grid_margin} );
+	$pr->text( " " . $t->{text}, $x, $y, $fonts->{comment} );
     }
 }
 
@@ -246,39 +215,29 @@ sub is_bar( $elt ) {
     exists( $elt->{class} ) && $elt->{class} eq "bar";
 }
 
-# Location and size of vertical bars
-sub yh( $y, $h, $pr ) {
-    my $d = $pr->{ps}->{grids}->{stretch} || 0.825;
-    return ( $y + 0.9 * $h,
-	     $h * $d * $pr->{ps}->{spacing}->{grid} );
-}
-
 sub pr_cellline( $x, $y, $lcr, $sz, $w, $col, $pr ) {
-    $x -= $w / 2;
-    $pr->vline( $x, yh($y,$sz,$pr), $w, $col );
+    $x -= $w / 2 * ($lcr + 1);
+    $pr->vline( $x, $y+0.9*$sz, $sz, $w, $col );
 }
 
 sub pr_barline( $x, $y, $lcr, $sz, $col, $pr ) {
     my $w = $sz / 10;		# glyph width = $w
-    $x -= $w / 2;
-    $x += $w if $lcr < 0;
-    $pr->vline( $x, yh($y,$sz,$pr), $w, $col );
+    $x -= $w / 2 * ($lcr + 1);
+    $pr->vline( $x, $y+0.9*$sz, $sz, $w, $col );
 }
 
 sub pr_dbarline( $x, $y, $lcr, $sz, $col, $pr ) {
     my $w = $sz / 10;		# glyph width = 3 * $w
-    $x -= 0.5 + $w * ($lcr + 1);
-#    $x -= $w * (( 0.5, 1.5, 2.5 )[1+$lcr]);
-    $pr->vline( $x, yh($y,$sz,$pr), $w, $col );
+    $x -= 1.5 * $w * ($lcr + 1);
+    $pr->vline( $x, $y+0.9*$sz, $sz, $w, $col );
     $x += 2 * $w;
-    $pr->vline( $x, yh($y,$sz,$pr), $w, $col );
+    $pr->vline( $x, $y+0.9*$sz, $sz, $w, $col );
 }
 
 sub pr_rptstart( $x, $y, $lcr, $sz, $col, $pr ) {
     my $w = $sz / 10;		# glyph width = 3 * $w
-    $x -= 0.5;
-    $x += $w if $lcr < 0;
-    $pr->vline( $x, yh($y,$sz,$pr), $w, $col );
+    $x -= 1.5 * $w * ($lcr + 1);
+    $pr->vline( $x, $y+0.9*$sz, $sz, $w, $col );
     $x += 2 * $w;
     $y += 0.55 * $sz;
     $pr->line( $x, $y, $x, $y+$w, $w, $col );
@@ -289,9 +248,8 @@ sub pr_rptstart( $x, $y, $lcr, $sz, $col, $pr ) {
 sub pr_rptvolta( $x, $y, $lcr, $sz, $symcol, $pr, $token ) {
     my $w = $sz / 10;		# glyph width = 3 * $w
     my $col = $pr->{ps}->{grids}->{volta}->{color};
-    $x += $w if $lcr < 0;
-    my $ret = $x -= $w / 2;
-    $pr->vline( $x, yh($y,$sz,$pr), $w, $col );
+    my $ret = $x -= 1.5 * $w * ($lcr + 1);
+    $pr->vline( $x, $y+0.9*$sz, $sz, $w, $col );
     $x += 2 * $w;
     my $font = $pr->{ps}->{fonts}->{grid};
     $pr->setfont($font);
@@ -308,9 +266,8 @@ sub pr_voltafinish( $x, $y, $width, $sz, $symcol, $pr ) {
 
 sub pr_rptend( $x, $y, $lcr, $sz, $col, $pr ) {
     my $w = $sz / 10;		# glyph width = 3 * $w
-    $x -= 2.5 * $w if $lcr >= 0;
-    $x += $w if $lcr < 0;
-    $pr->vline( $x + 2*$w, yh($y,$sz,$pr), $w, $col );
+    $x -= 1.5 * $w * ($lcr + 1);
+    $pr->vline( $x + 2*$w, $y+0.9*$sz, $sz, $w, $col );
     $y += 0.55 * $sz;
     $pr->line( $x, $y, $x, $y+$w, $w, $col );
     $y -= 0.4 * $sz;
@@ -319,10 +276,8 @@ sub pr_rptend( $x, $y, $lcr, $sz, $col, $pr ) {
 
 sub pr_rptendstart( $x, $y, $lcr, $sz, $col, $pr ) {
     my $w = $sz / 10;		# glyph width = 5 * $w
-    $lcr = 0;			# center
     $x -= 2.5 * $w * ($lcr + 1);
-    $x += $w if $lcr < 0;
-    $pr->vline( $x + 2*$w, yh($y,$sz,$pr), $w, $col );
+    $pr->vline( $x + 2*$w, $y+0.9*$sz, $sz, $w, $col );
     $y += 0.55 * $sz;
     $pr->line( $x,      $y, $x     , $y+$w, $w, $col );
     $pr->line( $x+4*$w, $y, $x+4*$w, $y+$w, $w, $col );
@@ -333,7 +288,7 @@ sub pr_rptendstart( $x, $y, $lcr, $sz, $col, $pr ) {
 
 sub pr_repeat( $x, $y, $lcr, $sz, $col, $pr ) {
     my $w = $sz / 3;		# glyph width = 3 * $w
-    $x -= 1.5 * $w;
+    $x -= 1.5 * $w * ($lcr + 1);
     my $lw = $sz / 10;
     $x -= $w / 2;
     $pr->line( $x, $y+0.2*$sz, $x + $w, $y+0.7*$sz, $lw );
@@ -342,28 +297,15 @@ sub pr_repeat( $x, $y, $lcr, $sz, $col, $pr ) {
     $pr->line( $x - 0.05*$sz, $y+0.2*$sz, $x + 0.02*$sz, $y+0.3*$sz, $lw );
 }
 
-sub pr_repeat2( $x, $y, $lcr, $sz, $col, $pr ) {
-    my $w = $sz / 4;		# glyph width = 4 * $w
-    $x -= 2.7 * $w;
-    my $lw = $sz / 10;
-    $x -= $w / 2;
-    $pr->line( $x, $y+0.2*$sz, $x + $w, $y+0.7*$sz, $lw );
-    $pr->line( $x, $y+0.6*$sz, $x + 0.07*$sz , $y+0.7*$sz, $lw );
-    $x += $w;
-    $pr->line( $x - $w/4, $y+0.2*$sz, $x + 0.75*$w, $y+0.7*$sz, $lw );
-    $x += 0.75 * $w;
-    $pr->line( $x - 0.05*$sz, $y+0.2*$sz, $x + 0.02*$sz, $y+0.3*$sz, $lw );
-}
-
 sub pr_endline( $x, $y, $lcr, $sz, $col, $pr ) {
     my $w = $sz / 10;		# glyph width = 2 * $w
-    $x -= 0.5 * $w * ($lcr + 1);
-    $x += $w if $lcr < 0;
-    $pr->vline( $x, yh($y,$sz,$pr), 2*$w );
+    $x -= 0.75 * $w * ($lcr + 1);
+    $pr->vline( $x, $y+0.85*$sz, 0.9*$sz, 2*$w );
 }
 
 ################ Hooks ################
 
-*pr_label_maybe = *ChordPro::Output::PDF::Song::pr_label_maybe;
+*font_bl        = *ChordPro::Output::PDF::font_bl;
+*pr_label_maybe = *ChordPro::Output::PDF::pr_label_maybe;
 
 1;
