@@ -9,10 +9,10 @@ my $pdf = "";			# for cache flush
 
 class ChordPro::Output::PDF::KeyboardDiagram;
 
-field $pr       :param;
+field $ps	:param;
 
 field $config;
-field $ps;
+field $pr;
 
 field $kw;
 field $kh;
@@ -26,7 +26,7 @@ field $pressed;
 
 ADJUST {
     $config	  = $::config;
-    $ps		  = $pr->{ps};
+    $pr		  = $ps->{pr};
     my $ctl	  = $ps->{kbdiagrams};
     $kw		  = $ctl->{width} || 6;
     $kh		  = $ctl->{height} || 6;
@@ -91,6 +91,10 @@ method hsp ( $elt, $dummy = 0 ) {
     $self->hsp0($elt) + $self->hsp1($ps);
 }
 
+sub font_bl ($font) {
+    &ChordPro::Output::PDF::font_bl($font);
+}
+
 my %keytypes =
   (  0 => [0,"L"],		# Left
      1 => [0,"B"],		# Black
@@ -110,7 +114,7 @@ my %keytypes =
 method draw ( $info, $x, $y, $dummy = 0 ) {
     return unless $info;
     my $w = $lw + $kw * $keys;
-    $fg = $info->{diagram} // $ps->{theme}->{foreground};
+    $fg = $info->{diagram} // "black"; # $ps->{theme}->{foreground};
 
     # Get (or infer) keys.
     my @keys = @{ChordPro::Chords::get_keys($info)};
@@ -132,7 +136,7 @@ method draw ( $info, $x, $y, $dummy = 0 ) {
     $name .= "?" unless @keys;
     $name = "<span color='$fg'>$name</span>"
       if $info->{diagram};
-    $pr->text( $name, $x + ($w - $pr->strwidth($name))/2, $y - $pr->font_bl($font) );
+    $pr->text( $name, $x + ($w - $pr->strwidth($name))/2, $y - font_bl($font) );
 }
 
 # Returns the complete diagram as an xo. This includes the core grid
@@ -144,7 +148,7 @@ method diagram_xo ($info) {
     return unless $info;
 
     my $col = $pressed // "red";
-    $fg = $info->{diagram} // $fg // $ps->{theme}->{foreground};
+    $fg = $info->{diagram} // "black"; # $ps->{theme}->{foreground};
     my $w = $lw + $kw * $keys;
     my $v = $kh;
 
