@@ -20,7 +20,7 @@ BUILD {
 	{ 'font-family'		    => 'serif',
 	  'font-size'		    => '10',
 	  'color'		    => 'black',
-	  'background-color'	    => 'none',
+	  'background-color'	    => 'white',
 	  'fill'		    => 'currentColor',
 	  'stroke'		    => 'none',
 	  'line-width'		    => 1,
@@ -216,7 +216,7 @@ method push ( @args ) {
 
     ## Presentation attributes.
     for ( keys %$args ) {
-	next if /^(element|class|style|id)$/;
+	next if /^element|class|style|id$/;
 	$ret->{$_} = $args->{$_};
     }
 
@@ -231,23 +231,16 @@ method push ( @args ) {
     ## Class style.
     if ( $args->{class} ) {
 	for ( split( ' ', $args->{class} ), "svg" ) {
-	    $self->merge( $ret, $css->{".$_"} )
-	      if exists( $css->{".$_"} );
-	    $self->merge( $ret, $css->{$args->{element}.".$_"} )
-	      if $args->{element} && exists( $css->{$args->{element}.".$_"} );
+	    next unless exists( $css->{".$_"} );
+	    $self->merge( $ret, $css->{".$_"} );
 	}
     }
 
-    ## ID (generic).
+    ## ID.
     if ( $args->{id} && exists( $css->{ "#" . $args->{id} } ) ) {
 	$self->merge( $ret, $css->{ "#" . $args->{id} } );
     }
 
-    ## ID (specific).
-    if ( $args->{id} && exists( $css->{ $args->{element} . "#" . $args->{id} } ) ) {
-	$self->merge( $ret, $css->{ $args->{element} . "#" . $args->{id} } );
-    }
-
     ## Style attribute.
     if ( $args->{style} ) {
 	$self->read_string( "__ {" . $args->{style} . "}" )
